#
# spec file for package python-rtslib-fb
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define dbdir %{_sysconfdir}/target
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-rtslib-fb
Version:        2.1.69
Release:        lp151.2.1
Summary:        API for Linux kernel SCSI target (aka LIO)
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            http://github.com/open-iscsi/rtslib-fb.git
Source:         %{name}-%{version}.tar.xz
Patch1:         rbd-support.patch
BuildRequires:  %{python_module pyudev}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pyudev
Requires(post): update-alternatives
Requires(postun): update-alternatives
Provides:       python-rtslib = %{version}-%{release}
Obsoletes:      python-rtslib
%if 0%{?sle_version} >= 150000
# explicit Provides advertising RBD support
Provides:       python-rtslib-rbd = %{version}
Obsoletes:      python-rtslib-rbd < %{version}
%endif
BuildArch:      noarch
%python_subpackages

%description
rtslib-fb is an object-based Python library for configuring the LIO generic
SCSI target, present in 3.x Linux kernel versions. rtslib-fb is licensed under
the Apache 2.0 license. Contributions are welcome

%prep
%setup -q
%if 0%{?sle_version} >= 150000
# RBD support is dependent on LIO changes present in the SLE/Leap kernel
%patch1 -p1
%endif

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}/%{_bindir}/targetctl
%fdupes %{buildroot}
install -d -m755 %{buildroot}%{_mandir}/man5
install -m644 doc/saveconfig.json.5 %{buildroot}%{_mandir}/man5
%python_clone -a %{buildroot}%{_mandir}/man5/saveconfig.json.5
install -d -m755 %{buildroot}%{_mandir}/man8
install -m644 doc/targetctl.8 %{buildroot}%{_mandir}/man8
%python_clone -a %{buildroot}%{_mandir}/man8/targetctl.8
install -d -m755 %{buildroot}/%{dbdir}
install -d -m755 %{buildroot}/%{dbdir}/pr
install -d -m755 %{buildroot}/%{dbdir}/alua

%post
%python_install_alternative targetctl targetctl.8 saveconfig.json.5

%postun
%python_uninstall_alternative targetctl

%files %{python_files}
%python_alternative %{_bindir}/targetctl
%{python_sitelib}/*
%doc COPYING README.md
%doc %python_alternative %{_mandir}/man5/saveconfig.json.5.gz
%doc %python_alternative %{_mandir}/man8/targetctl.8.gz
%dir %{dbdir}
%dir %{dbdir}/pr
%dir %{dbdir}/alua

%changelog
* Fri Dec  7 2018 ddiss@suse.com
- Enable RBD support for SLE/Leap 15+ (bsc#1118516)
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Oct 18 2018 opensuse-packaging@opensuse.org
- Update to version 2.1.69:
  * version 2.1.fb69
  * fix compiler warning
  * version 2.1.fb68
  * Fix typo
  * - remove underscore in hostname
  * tcm: allow to enable asynchronous I/O for file backing stores
  * saveconfig: way for block-level save with delete command
  * saveconfig: fix missing import
  * saveconfig: handle no attr exception in _parse_info()
  * saveconfig: fix failure in absence of save file
  * saveconfig: dump control string containing control=value tuples
  * restoreconfig: fix alua tpg config setup
  * tcmu: add control constructor arg
  * save_to_file: support saveconfig at storage object level
  * Allow creating more than 256 LUNs per target
  * Ship a systemd service file
  Which replaces python-rtslib-fb-2.1.67.tar.xz with
  python-rtslib-fb-2.1.69.tar.xz, and updates the SPEC file as well.
* Tue Apr 10 2018 ddiss@suse.com
- Merge RBD support from non-fb version (bsc#1079329)
  + rbd-support.patch (SLE/Leap only, due to LIO kernel dependency)
  + Add explicit Provides for "python-rtslib-rbd"
* Tue Apr 10 2018 ddiss@suse.com
- Automatically generate version string from upstream tag
  + Retain current fb-removed version format used
  + Rename rtslib-fb-2.1.fb67.tar.xz to python-rtslib-fb-2.1.67.tar.xz and
    cleanup hardcoded duplicate name/version values in spec
* Mon Apr  9 2018 lduncan@suse.com
- Update to version 2.1.fb67:
  * Add missing dependency on six in setup.py
  * Display a more meaningful error when targetcli cannot change "dbroot"
  * Raise an error about failing to change the dbroot value only if the directory does not exist
  * More compatibility syntax for legacy distros
  * Remove hba-only directories in clear_existing()
  * Correct name for Xen pvscsi
  * version 2.1.fb65
  * Fix unqualified reference to pyudev.Device
  * version 2.1.fb66
  * create: remove stale hba-only dir
  * version 2.1.fb67
- This replaced rtslib-fb-2.1.fb64.tar.xz with
  rtslib-fb-2.1.fb67.tar.xz, and it also removed
  the patch correct-name-for-xen-pvscsi.patch,
  since it is already in the updated tarball
* Sun Feb 25 2018 olaf@aepfle.de
- Fix upgrade path by provide/obsolete python-rtslib (bsc#1082693)
* Wed Jan 24 2018 lduncan@suse.com
- Fix incorrect naming for XEN (bsc#1076455), adding patch:
  * correct-name-for-xen-pvscsi.patch
* Tue Jan  9 2018 tchvatal@suse.com
- Fix the conflict to the rtslib properly
* Wed Jan  3 2018 tchvatal@suse.com
- Drop the epydoc dependency/documentation generating from the package
  to allow building in py3 only enviroment
* Sun Dec 10 2017 lduncan@suse.com
- Converting RPM SPEC file to singlespec format (bsc#1045332),
  updating SPEC file only.
- ran 'spec-cleaner' on SPEC file to clean it up.
- Converted from manually-added rtslib-fb-2.1.fb64.tar.gz to
  tar_scm service-retrieved rtslib-fb-2.1.fb64.tar.xz
* Thu Aug 17 2017 lszhu@suse.com
- Update to version 2.1.fb64
  * Improve ALUA and TCMU support, as well as moving the default
  directory for APTPL files from /var/target to /etc/target
  for better FHS compliance.
  * Remove patch Switch-target-driver-DB-root-dir-to-etc-target.patch
  from the spec file because upstream already has this change.
* Thu Jun  8 2017 lduncan@suse.com
- Enable Persistent Reservations (bsc#1042944):
  * Add patch Switch-target-driver-DB-root-dir-to-etc-target.patch
  * Add /etc/target/pr and /etc/target/alua to SPEC file
* Thu Apr 13 2017 hare@suse.com
- Update to version 2.1.63 (bsc#1032833):
  * Get/Set LUN's ALUA group
  * Add ALUA restore support
  * Delete ALUA groups with its storage object
  * version 2.1.fb62
  * Do not set alua_tg_pt_gp if not supported
  * Add ability to invalidate caches
  * Add ALUA supported method
  * Don't raise exception when getting/setting a LUNs ALUA group
  * update to 2.1.fb63
* Fri Jun 24 2016 lduncan@suse.com
- Updated spec file: Removed Provides/Obsoletes for python-rtslib,
  and added Conflicts for same (bsc#986475)
* Tue Jun 14 2016 lduncan@suse.com
- Fixing build issue: removed 'noarch' from main package
* Tue Jun 14 2016 lduncan@suse.com
- Updated SPEC file:
  * added Requires for pyudev (bsc#984563)
  * removed BuildRequires of pyudev for doc sub-package
* Wed Apr 20 2016 lduncan@suse.com
- Update to version 2.1.fb60
  * no changelog available, but git log shows 59 changes,
    some trivial
* Tue May 12 2015 benoit.monin@gmx.fr
- update to version 2.1.51:
  * no changelog available
* Wed Sep  3 2014 dmueller@suse.com
- update to 2.1.49:
  * Improve error message when NetworkPortal restore fails
  * Python 3.x porting fixes
  * targetctl: A missing restore file is not an error
  * Add a message if no configfile is found
  * Add StorageObjectFactory
  * Convert all exceptions in set_parameter/attribute to RTSLibError
  * Change set_parameters/attributes to take an err_func
  * Fix missing err_func parameter to set_attributes
  * '!' allowed character in block and partition names
  * Don't add to cache if cfs create fails
  * Don't lower-case return values from _parse_info functions
* Tue Jan 14 2014 speilicke@suse.com
- Conflict with python-rtslib
* Mon Jan 13 2014 dmueller@suse.com
- update to 2.1.43:
  * various bugfixes
* Mon Oct 28 2013 dmueller@suse.com
- Initial package (2.1.40)
